import { Album, Image } from "@/generated/prisma";
import NextImage from "next/image";
import Link from "next/link";

type Props = {
  album: Album & {
    coverImage: Image | null;
  };
  gallerySlug: string;
};

export default function AlbumCard({ album, gallerySlug }: Props) {
  const href = `/galleries/${gallerySlug}/${album.slug}`;
  const cover = album.coverImage;

  return (
    <Link
      href={href}
      className="group relative overflow-hidden rounded-lg border bg-background shadow transition hover:shadow-lg"
    >
      <div className="aspect-[4/3] w-full relative">
        {cover ? (
          <NextImage
            src={`/api/image/thumbnails/${cover.fileKey}.webp`}
            alt={cover.imageName}
            fill
            className="object-cover"
          />
        ) : (
          <div className="flex items-center justify-center h-full w-full bg-muted text-muted-foreground text-sm">
            No cover image
          </div>
        )}

        {/* Overlay: Album label */}
        <div className="absolute top-1 left-1 bg-black/60 text-white text-xs px-2 py-0.5 rounded z-10">
          Album
        </div>

        {/* Bottom: Album name */}
        <div className="absolute bottom-0 left-0 w-full bg-black/50 text-white text-sm px-2 py-1 line-clamp-1 truncate">
          {album.name}
        </div>
      </div>
    </Link>
  );
}
